- formFixed
formula for fixed part of longitudinal submodel with response variable
- formRandom
formula for random part of longitudinal submodel without response variable
- formGroup
formula specifying the cluster variable (e.g. = ~ subject)
- data
dataset of observed variables
- tau
the quantile(s) to be estimated. This must be a number between 0 and 1, otherwise the execution is stopped. If more than one quantile is specified, rounding off to the 4th decimal must give non–duplicated values of tau, otherwise the execution is stopped.
- RE_ind
Boolean denoting if the random effects are assumed independent ; default is FALSE
- n.chains
the number of parallel chains for the model; default is 1.
- n.iter
integer specifying the total number of iterations; default is 10000
- n.burnin
integer specifying how many of n.iter to discard as burn-in ; default is 5000
- n.thin
integer specifying the thinning of the chains; default is 1
- n.adapt
integer specifying the number of iterations to use for adaptation; default is NULL
- precision
variance by default for vague prior distribution
- save_jagsUI
If TRUE (by default), the output of jagsUI package is returned by the function. Warning, if TRUE, the output can be large.
- parallel
see jagsUI::jags() function